@@ -1,11 +1,5 @@
 """
 Manages data from a collection of flights or profiles at a specific location
-
-Authors Brian Greene, Jessica Blunt, Tyler Bell, Gus Azevedo \n
-Copyright University of Oklahoma Center for Autonomous Sensing and Sampling
-2019
-
-Component of Profiles v1.0.0
 """
 import os
 import netCDF4
@@ -17,7 +11,6 @@ from profiles.Raw_Profile import Raw_Profile
 from profiles.Thermo_Profile import Thermo_Profile
 from profiles.Wind_Profile import Wind_Profile
 import profiles.utils as utils
-#from memory_profiler import profile
 from copy import deepcopy
 
 
@@ -25,7 +18,6 @@ class Profile_Set():
     """ This class manages data (in the form of Profile objects) from one or
     many flights.
 
-    :var Location location: information about the location of the flights
     :var list<Profile> profiles: list of Profile objects at this location
     :var bool ascent: True if data from the ascending leg of the profile is \
        to be used. If False, the descending leg will be processed instead
@@ -36,12 +28,12 @@ class Profile_Set():
        automatically-determined start, peak, and end times of each profile
     :var int profile_start_height: either passed to the constructor or \
        provided by the user during processing
+    :var Meta meta: reads and processes metadata from oucass-checklist
     """
 
     def __init__(self, resolution=10, res_units='m', ascent=True,
                  dev=False, confirm_bounds=True, profile_start_height=None,
-                 nc_level='none',
-                 coefs_path=os.path.join(utils.package_path, "coefs")):
+                 nc_level='none'):
         """ Creates a Profiles object.
 
         :param int resolution: resolution to which data should be
@@ -73,11 +65,10 @@ class Profile_Set():
         self.confirm_bounds = confirm_bounds
         self.profiles = []
         self.profile_start_height = profile_start_height
-        self.meta = None
+        #self.meta = None
         self._nc_level = nc_level
-        self.root_dir = ""
+        self._root_dir = ""
         self._base_start = None
-        self.coefs_path = coefs_path
 
     def add_all_profiles(self, file_path, scoop_id=None,
                          meta_flight_path=None, meta_header_path=None):
@@ -86,34 +77,31 @@ class Profile_Set():
 
         :param str file_path: the data file
         :param str scoop_id: the identifier of the sensor package used
+        :param str meta_flight_path: path to the "flight" file generated by oucass-checklist
+        :param str meta_header_path: path to the "header" file generated by oucass-checklist
         """
         file_path = os.path.abspath(file_path)
         file_dir = os.path.dirname(file_path) + "/"
-        if(self.root_dir is ""):
-            self.root_dir = file_dir
+        if(self._root_dir is ""):
+            self._root_dir = file_dir
         else:
             match_up_to = -1
-            for i in range(len(self.root_dir)):
+            for i in range(len(self._root_dir)):
                 if i < len(file_dir):
-                    if self.root_dir[i] == file_dir[i]:
+                    if self._root_dir[i] == file_dir[i]:
                         match_up_to = i
                     else:
-                        # print(self.root_dir[i], file_dir[i])
                         break
                 else:
-                    # print(self.root_dir[:i-1], file_dir[:i-1])
                     break
-            # print(self.root_dir)
-            self.root_dir = self.root_dir[:match_up_to+2]
-            # print(self.root_dir)
-            self.root_dir = self.root_dir[:self.root_dir.rindex("/")+1]
-            # print(self.root_dir)
+            self._root_dir = self._root_dir[:match_up_to+2]
+            self._root_dir = self._root_dir[:self._root_dir.rindex("/")+1]
+
         # Process altitude data for profile identification
         raw_profile_set = Raw_Profile(file_path, self.dev, scoop_id,
                                       nc_level=self._nc_level,
                                       meta_header_path=meta_header_path,
-                                      meta_flight_path=meta_flight_path,
-                                      coefs_path=self.coefs_path)
+                                      meta_flight_path=meta_flight_path)
         pos = raw_profile_set.pos_data()
 
         # Identify the start, peak, and end indices of each profile
@@ -133,10 +121,6 @@ class Profile_Set():
                            nc_level=self._nc_level,
                            base_start=self._base_start)
             self.profiles.append(prof)
-            if self.meta is None:
-                self.meta = prof.meta
-            else:
-                self.meta.combine(prof.meta)
 
             if self._base_start is None:
                 self._base_start = self.profiles[-1]._base_start
@@ -151,12 +135,15 @@ class Profile_Set():
                                              profile_start_height=self
                                              .profile_start_height,
                                              nc_level=self._nc_level,
-                                             base_start=self._base_start,
-                                             coefs_path=self.coefs_path))
+                                             base_start=self._base_start))
 
         self.profiles.sort()
         print(len(self.profiles), "profile(s) including those added from file",
               file_path)
+        #if self.meta is None:
+        #    self.meta = prof.meta
+        #else:
+        #    self.meta.combine(prof.meta)
 
     def add_profile(self, file_path,
                     time=dt.datetime(dt.MINYEAR, 1, 1, tzinfo=None),
@@ -170,31 +157,30 @@ class Profile_Set():
            (used only if profile_num is not specified)
         :param int profile_num: use the nth profile in the file
         :param str scoop_id: the identifier of the sensor package used
+        :param str meta_flight_path: path to the "flight" file generated by oucass-checklist
+        :param str meta_header_path: path to the "header" file generated by oucass-checklist
         """
 
         file_dir = os.path.dirname(file_path)
-        if(self.root_dir is ""):
-            self.root_dir = file_dir
+        if(self._root_dir is ""):
+            self._root_dir = file_dir
         else:
             match_up_to = -1
-            for i in range(len(self.root_dir)):
+            for i in range(len(self._root_dir)):
                 if i < len(file_dir):
-                    if self.root_dir[i] == file_dir[i]:
+                    if self._root_dir[i] == file_dir[i]:
                         match_up_to = i
                     else:
-                        # print(self.root_dir[i], file_dir[i])
                         break
                 else:
-                    # print(self.root_dir[:i-1], file_dir[:i-1])
                     break
-            self.root_dir = os.path.dirname(self.root_dir[0:match_up_to+1])
+            self._root_dir = os.path.dirname(self._root_dir[0:match_up_to+1])
 
         # Process altitude data for profile identification
         raw_profile = Raw_Profile(file_path, self.dev, scoop_id,
                                   nc_level=self._nc_level,
                                   meta_header_path=meta_header_path,
-                                  meta_flight_path=meta_flight_path,
-                                  coefs_path=self.coefs_path)
+                                  meta_flight_path=meta_flight_path)
         pos = raw_profile.pos_data()
 
         # Identify the start, peak, and end indices of each profile
@@ -211,8 +197,7 @@ class Profile_Set():
                                          raw_profile=raw_profile,
                                          profile_start_height=self
                                          .profile_start_height,
-                                         nc_level=self._nc_level,
-                                         coefs_path=self.coefs_path))
+                                         nc_level=self._nc_level))
         else:
             for profile_num_guess in range(len(index_list)):
                 # Check if this profile is the first to start after time
@@ -226,8 +211,7 @@ class Profile_Set():
                                          raw_profile=raw_profile,
                                          profile_start_height=self
                                          .profile_start_height,
-                                         nc_level=self._nc_level,
-                                         coefs_path=self.coefs_path))
+                                         nc_level=self._nc_level))
 
                 # No need to add any more profiles from this file
                 break
@@ -380,18 +364,19 @@ class Profile_Set():
 
         main_file.close()
 
+    """
     def save_netCDF(self, file_path):
-        """ Stores all attributes of this Profile_Set object as a NetCDF
+        Stores all attributes of this Profile_Set object as a NetCDF
 
         :param string file_path: the file name to which attributes should be
            saved
-        """
-        main_file = netCDF4.Dataset(os.path.join(self.root_dir,
+        
+        main_file = netCDF4.Dataset(os.path.join(self._root_dir,
                                                  "processed", file_path),
                                     "w", format="NETCDF4", mmap=False)
         if self.meta is not None:
             self.meta.write_public_meta(
-                os.path.join(self.root_dir,"processed", file_path)[:-3]
+                os.path.join(self._root_dir,"processed", file_path)[:-3]
                 + "_meta.txt")
         main_file.dev = str(self.dev)
         main_file.resolution = self.resolution
@@ -417,7 +402,7 @@ class Profile_Set():
                     rh_var[:] = thermo.rh.magnitude
                     rh_var.units = str(thermo.rh.units)
                 except Exception:
-                    print("")
+                    continue
                 # TEMP
                 try:
                     temp_var = profile_group.createVariable("temp", "f8",
@@ -425,7 +410,7 @@ class Profile_Set():
                     temp_var[:] = thermo.temp.magnitude
                     temp_var.units = str(thermo.temp.units)
                 except Exception:
-                    print("")
+                    continue
                 # MIXING RATIO
                 try:
                     mr_var = profile_group.createVariable("mr", "f8",
@@ -433,7 +418,7 @@ class Profile_Set():
                     mr_var[:] = thermo.mixing_ratio.magnitude
                     mr_var.units = str(thermo.mixing_ratio.units)
                 except Exception:
-                    print("")
+                    continue
                 # TIME
                 try:
                     time_var = profile_group.createVariable("time", "f8",
@@ -444,7 +429,7 @@ class Profile_Set():
                     time_var.units = \
                         'microseconds since 2010-01-01 00:00:00:00'
                 except Exception:
-                    print("")
+                    continue
                 # ALT
                 try:
                     alt_var = profile_group.createVariable("alt", "f8",
@@ -452,7 +437,7 @@ class Profile_Set():
                     alt_var[:] = thermo.alt.magnitude
                     alt_var.units = str(thermo.alt.units)
                 except Exception:
-                    print("")
+                    continue
                 # PRES
                 try:
                     pres_var = profile_group.createVariable("pres", "f8",
@@ -460,7 +445,7 @@ class Profile_Set():
                     pres_var[:] = thermo.pres.magnitude
                     pres_var.units = str(thermo.pres.units)
                 except Exception:
-                    print("")
+                    continue
 
             #
             # Wind
@@ -477,7 +462,7 @@ class Profile_Set():
                     dir_var[:] = wind.dir.magnitude
                     dir_var.units = str(wind.dir.units)
                 except Exception:
-                    print("")
+                    continue
                 # SPEED
                 try:
                     spd_var = profile_group.createVariable("speed", "f8",
@@ -485,7 +470,7 @@ class Profile_Set():
                     spd_var[:] = wind.speed.magnitude
                     spd_var.units = str(wind.speed.units)
                 except Exception:
-                    print("")
+                    continue
                 # U
                 try:
                     u_var = profile_group.createVariable("u", "f8",
@@ -493,14 +478,14 @@ class Profile_Set():
                     u_var[:] = wind.u.magnitude
                     u_var.units = str(wind.u.units)
                 except Exception:
-                    print("")
+                    continue
                 # V
                 try:
                     v_var = profile_group.createVariable("v", "f8", ("time",))
                     v_var[:] = wind.v.magnitude
                     v_var.units = str(wind.v.units)
                 except Exception:
-                    print("")
+                    continue
                 # PRES
                 try:
                     pres_var = profile_group.createVariable("pres", "f8",
@@ -508,7 +493,7 @@ class Profile_Set():
                     pres_var[:] = wind.pres.magnitude
                     pres_var.units = str(wind.pres.units)
                 except Exception:
-                    print("")
+                    continue
                 # TIME
                 try:
                     time_var = profile_group.createVariable("time", "f8",
@@ -519,7 +504,7 @@ class Profile_Set():
                     time_var.units = \
                         'microseconds since 2010-01-01 00:00:00:00'
                 except Exception:
-                    print("")
+                    continue
                 # ALT
                 try:
                     alt_var = profile_group.createVariable("alt", "f8",
@@ -527,7 +512,7 @@ class Profile_Set():
                     alt_var[:] = wind.alt.magnitude
                     alt_var.units = str(wind.alt.units)
                 except Exception:
-                    print("")
+                    continue
 
 
         #
@@ -542,6 +527,7 @@ class Profile_Set():
                     main_file.renameAttribute("key", key)
 
         main_file.close()
+    """
 
     def __str__(self):
         to_return = "=====================================================\n" \
