@@ -1,11 +1,5 @@
 """
 Utils contains misc. functions to aid in data analysis.
-
-Authors Brian Greene, Jessica Blunt, Tyler Bell, Gus Azevedo \n
-Copyright University of Oklahoma Center for Autonomous Sensing and Sampling
-2019
-
-Component of Profiles v1.0.0
 """
 import sys
 import os
@@ -18,9 +12,13 @@ from datetime import timedelta
 from pandas.plotting import register_matplotlib_converters
 from pint import UnitStrippedWarning
 from metpy.units import units as u
+from azure.cosmosdb.table.tableservice import TableService
+from azure.cosmosdb.table.models import Entity
+from .Coef_Manager import Coef_Manager
+
 
 package_path = os.path.dirname(os.path.abspath(__file__))
-
+coef_manager = Coef_Manager()  # All required input is given in __init__.py
 
 warnings.filterwarnings("ignore", category=RuntimeWarning)
 warnings.filterwarnings("error", category=UnitStrippedWarning)
@@ -40,53 +38,52 @@ def regrid_base(base=None, base_times=None, new_res=None, ascent=True,
     :param bool ascent: True if data from ascending leg of profile is to be \
        analyzed, false if descending
     :param pint.UnitRegistry units: The unit registry defined in Profile
+    :param tuple indices: start and end times
+    :param Quantity base_start: lowest altitude value of gridded_base
     :rtype: tuple(np.Array<Datetime>, np.Array<Quantity>)
     :return: times at which the craft is at vertical points n*res above \
        the profile starting height and the corrosponding base values
     """
     # Use negative pressure so that the max of the data list is the peak
+
+    # Change indices to a 2-tuple with indices instead of times, start and end
+    if indices[0] is None:
+        indices = (0, len(base))
+    else:
+        a = list(base_times).index(indices[0])
+        if ascent:
+            b = list(base_times).index(indices[1])
+        else:
+            b = list(base_times).index(indices[2])
+        indices = (a, b)
+
     if new_res.dimensionality == units.Pa.dimensionality:
         base = -1*base
         if base_start is not None:
             base_start = -1*base_start
 
     # Regrid base
-    if ascent:
-        if base_start is None:
-            new_base = np.arange((base[0] + 0.5*new_res).magnitude, (max(base) - 0.5*new_res).magnitude,
-                                 new_res.magnitude)
-        else:
-            new_base = np.arange(base_start.magnitude, (max(base) - 0.5 * new_res).magnitude, new_res.magnitude)
+    if base_start is None:
+        new_base = np.arange((base[indices[0]] + 0.5*new_res).magnitude,
+                             (base[indices[1]] - 0.5*new_res).magnitude,
+                             new_res.magnitude)
     else:
-        if base_start is None:
-            new_base = np.arange((base[0] - 0.5*new_res).magnitude, (min(base) +
-                                 0.5*new_res).magnitude,
-                                 -1*new_res.magnitude)
-        else:
-            new_base = np.arange(base_start.magnitude, (min(base) + 0.5 * new_res).magnitude,
-                                 -1 * new_res.magnitude)
+        new_base = np.arange(base_start.magnitude,
+                             (base[indices[1]] - 0.5 * new_res).magnitude,
+                             new_res.magnitude)
+
     new_base = np.array(new_base) * base.units
 
-    # Find times corresponding to regridded base
-    new_times = []
+    ind_in_grid = []
+    i = indices[0]
     for elem in new_base:
-        if indices[0] is None:
-            if ascent:
-                closest_base_val_ind = next(x for x, val in enumerate(base)
-                                            if val > elem)
-            else:
-                closest_base_val_ind = next(x for x, val in enumerate(base)
-                                            if val < elem)
-        else:
-            if ascent:
-                closest_base_val_ind = next(x for x, val in enumerate(base)
-                                            if val > elem and base_times[x] >=
-                                            indices[0])
-            else:
-                closest_base_val_ind = next(x for x, val in enumerate(base)
-                                            if val < elem and base_times[x] >=
-                                            indices[1])
-        new_times.append(base_times[closest_base_val_ind])
+        while base[i] < elem and i < indices[1]:
+            i += 1
+        ind_in_grid.append(i)
+        i += 1
+
+    new_times = [base_times[i] for i in ind_in_grid]
+
 
     if new_res.dimensionality == units.Pa.dimensionality:
         new_base = -1*new_base
@@ -125,20 +122,20 @@ def regrid_data(data=None, data_times=None, gridded_times=None, units=None):
         data_seg_start_ind = None
         data_seg_end_ind = None
 
-        while(data_index < len(data)):
+        while data_index < len(data):
             if data_times[data_index] >= start_time:
                 data_seg_start_ind = data_index
                 break
             data_index += 1
 
-        while(data_index < len(data)):
+        while data_index < len(data):
             if data_times[data_index] >= end_time:
                 data_seg_end_ind = data_index
                 break
             data_index += 1
 
         # Calculate and store the segment mean
-        if (data_seg_start_ind is not None and data_seg_end_ind is not None):
+        if data_seg_start_ind is not None and data_seg_end_ind is not None:
             gridded_data.append(np.nanmean(data.magnitude[data_seg_start_ind:
                                            data_seg_end_ind]))
 
@@ -147,7 +144,8 @@ def regrid_data(data=None, data_times=None, gridded_times=None, units=None):
     return (gridded_data)
 
 
-def temp_calib(resistance, sn, coefs_path):
+
+def temp_calib(resistance, sn):
     """ Converts resistance to temperature using the coefficients for the \
        sensor specified OR generalized coefficients if the serial number (sn)\
        is not recognized.
@@ -158,18 +156,32 @@ def temp_calib(resistance, sn, coefs_path):
     :rtype: list<Quantity>
     :return: list of temperatures in K
     """
-
-    coefs = pd.read_csv(os.path.join(coefs_path, 'MasterCoefList.csv'))
-    a = float(coefs.A[coefs.SerialNumber == sn][coefs.SensorType == "Imet"])
-    b = float(coefs.B[coefs.SerialNumber == sn][coefs.SensorType == "Imet"])
-    c = float(coefs.C[coefs.SerialNumber == sn][coefs.SensorType == "Imet"])
-    # print("Temperature calculated from resistance using coefficients \n",
-    #      a, b, c)
+    coefs = coef_manager.get_coefs("Imet", sn)
+    a = float(coefs["A"])
+    b = float(coefs["B"])
+    c = float(coefs["C"])
 
     return np.power(np.add(np.add(b * np.log(resistance), a),
                     c * np.power(np.log(resistance), 3)), -1)
 
 
+def rh_calib(raw, sn):
+    """ Adds the sensor offsets
+
+    :param list<Quanitity> raw: raw RH
+    :param int sn: serial number of the humidity sensor
+    :rtype: list<Quantity>
+    :return: list of calibrated rh
+    """
+    offset = coef_manager.get_coefs('RH', sn)['A']
+    try:
+        offset = float(coef_manager.get_coefs('RH', sn)['A']) / 1000
+    except Exception:
+        offset = 0
+
+    return np.add(raw, offset)
+
+
 def qc(data, max_bias, max_variance):
     """ Determines which sensors are not reliable from a given set. Be sure
        to only include like sensors (not both temperature inside and outside
